cog_cat: Administer Cognitive Tests Using Computerized Adaptive Testing
Description
This function accepts an RDA file or a list containing selected objects and
returns omega estimates, the standard error of omega, and the optimal next
condition to administer for single-subject computerized adaptive testing.
Adaptive testing is guided by D-optimality (see Segall, 2009).
A list with elements for omega parameter estimates (omega1),
standard error of the estimates (se_omega), and the next condition to
administer (next_condition).
Arguments
rda
An RDA file (or list) containing y, kappa, gamma, lambda,
condition, omega_mu, omega_sigma2, zeta_mu, zeta_sigma2, nu_mu, and
nu_sigma2. y should be a 1 by IJ row vector. All items not administered
should have NA values in y. See package documentation for definitions and
dimensions of these other objects.
obj_fun
A function that calculates predictions and log-likelihood
values for the selected model (character).
int_par
Intentional parameters. That is, the parameters to optimize
precision (scalar).
References
Segall, D. O. (2009). Principles of Multidimensional Adaptive Testing. In W.
J. van der Linden & C. A. W. Glas (Eds.), Elements of Adaptive Testing
(pp. 57-75). https://doi.org/10.1007/978-0-387-85461-8_3