Learn R Programming

cogirt (version 1.0.0)

cogirt-package: cogirt: Cognitive Testing Using Item Response Theory

Description

Psychometrically analyze latent individual differences related to tasks, interventions, or maturational/aging effects in the context of experimental or longitudinal cognitive research using methods first described by Thomas et al. (2020) tools:::Rd_expr_doi("10.1177/0013164420919898").

Arguments

Author

Maintainer: Michael Thomas michael.l.thomas@colostate.edu