This function calculates mhrm parameter estimates for multiple chains.
mhrm(
y = y,
obj_fun = NULL,
link = NULL,
est_omega = TRUE,
est_lambda = TRUE,
est_zeta = TRUE,
est_nu = TRUE,
omega0 = NULL,
gamma0 = NULL,
lambda0 = NULL,
zeta0 = NULL,
nu0 = NULL,
kappa0 = NULL,
omega_mu = NULL,
omega_sigma2 = NULL,
lambda_mu = NULL,
lambda_sigma2 = NULL,
zeta_mu = NULL,
zeta_sigma2 = NULL,
nu_mu = NULL,
nu_sigma2 = NULL,
constraints = NULL,
J = NULL,
M = NULL,
N = NULL,
verbose = TRUE,
...
)List with elements for all parameters estimated, information values for all parameters estimated, and the model log-likelihood value.
Item response matrix (K by IJ).
A function that calculates predictions and log-likelihood values for the selected model (character).
Choose between "logit" or "probit" link functions.
Determines whether omega is estimated (logical).
Determines whether lambda is estimated (logical).
Determines whether zeta is estimated (logical).
Determines whether nu is estimated (logical).
Starting values for omega.
Either a matrix of contrast codes (JM by MN) or the name in quotes of the desired R stats contrast function (i.e., "contr.helmert", "contr.poly", "contr.sum", "contr.treatment", or "contr.SAS"). If using the R stats contrast function the user must also specify J, M, and N, as well as ensure that items in y are arranged so that the first set of I items correspond to the first level if the contrast, the next set of I items correspond to the second level of the contrast, etc. For example, in an experiment with two conditions (i.e., J = 2) where the user requests two contrasts (i.e., N = 2) from the "contr.treatment" function, the first set of I items will all receive a contrast code of 0 and the second set of I items will all receive a contrast code of 1. In an experiment with three conditions (i.e., J = 3) where the user requests three contrasts (i.e., N = 3) from the "contr.poly" function, first set of I items will receive the lowest value code for linear and quadratic contrasts, the second set of I items will all receive the middle value code for linear and quadratic contrasts, and the last set of I items will all receive the highest value code for linear and quadratic contrasts.
Item slope matrix (IJ by JM).
Starting values for zeta.
Starting values for nu (IJ by 1).
Item guessing matrix (IJ by 1).
Vector of means prior for omega (1 by MN).
Covariance matrix prior for omega (MN by MN).
Mean prior for lambda (1 by JM)
Covariance prior for lambda (JM by JM)
Vector of means prior for zeta (1 by JM).
Covariance matrix prior for zeta (JM by JM).
Prior mean for nu (scalar).
Prior variance for nu (scalar).
Item parameter constraints.
Number of conditions (required if using the R stats contrast function).
Number of ability (or trait) dimensions (required if using the R stats contrast function).
Number of contrasts including intercept (required if using the R stats contrast function).
Logical (TRUE or FALSE) indicating whether to print progress.
Additional arguments.
Cai, L. (2010). High-dimensional exploratory item factor analysis by a Metropolis-Hastings Robbins-Monro algorithm. Psychometrika, 75(1), 33-57.
Cai, L. (2010). Metropolis-Hastings Robbins-Monro algorithm for confirmatory item factor analysis. Journal of Educational and Behavioral Statistics, 35(3), 307-335.