Sternberg task accuracy data collected from an online experiment. The condition vector indicates working memory load level (2, 4, 6, 8, 10, or 12 items).The key indicates whether items are targets (1) or distractors (2).
sternbergA list with the following elements:
Matrix of dichotomous responses.
Item key vector where 1 indicates target and 2 indicates distractor (IJ)
Condition vector indiciting distinct conditions or time points.