This function provides summary statistics for simulated computerized adaptive testing.
# S3 method for cog_cat_sim
summary(object, ...)This function does not return a value to the R environment. Instead, it prints a comprehensive summary of the simulated computerized adaptive testing results to the console. The output includes model name and simulation settings as well as summary statistics for each parameter of interest. The function is intended for interactive use.
An object of class 'cog_cat_sim'.
Additional arguments.